<?php
	class intellectmoneyPayment extends payment {
		/**
		* Статусы платежа (см. документацию по подключению im Money) 
		*/
		const STATUS_INPROCESS = 3;
		const STATUS_ACCEPTED  = 5;
		
		public function validate() { return true; }
		
		public function process($template = null) {
			$this->order->order();
			$currency = strtoupper( mainConfiguration::getInstance()->get('system', 'default-currency') );
			$amount = number_format($this->order->getActualPrice(), 2, '.', '');
			$param = array();
			$param["formAction"] = "https://merchant.intellectmoney.ru";
			$param["eshopId"] = $this->object->eshopId;
			$param["orderId"] = $this->order->id;
			$param["recipientAmount"] = $amount;
			$param["recipientCurrency"] = $currency;
			$param["serviceName"] = "Payment for order " . $this->order->id;
			$param["version"] = "2"; // May be 1 or 2, see documentation
			$this->order->setPaymentStatus('initialized');
			list($templateString) = def_module::loadTemplates("tpls/emarket/payment/intellectmoney/".$template.".tpl", "form_block");
			return def_module::parseTemplate($templateString, $param);
		}
		
		public function poll() {
			$buffer = outputBuffer::current();
			$buffer->clear();
			$buffer->contentType("text/plain");
			if($this->checkSignature()) {
				$status = getRequest("paymentStatus");
				switch($status) {
					case intellectmoneyPayment::STATUS_INPROCESS : { 
						$recipientAmount = (float) getRequest("recipientAmount");
						$checkAmount = (float) $this->order->getActualPrice();						
						if(($recipientAmount - $checkAmount) < (float)0.001) { // Almost equals
							$this->order->setPaymentStatus('validated');
							$this->order->payment_document_num = getRequest('paymentId');
							$buffer->push("OK");							
						} else {
							$this->order->setPaymentStatus('declined');
							$buffer->push("failed");							
						}						
						break;
					}
					case intellectmoneyPayment::STATUS_ACCEPTED  : { 
						$this->order->setPaymentStatus('accepted'); 
						$buffer->push("OK");
						break;
					}
				}				
			} else {
				$buffer->push("failed");
			}
			$buffer->end();			
		}
		
		private function checkSignature() {
		
			$secretKey = $this->object->sekretkey;
		
			if(getRequest('secretKey'))
			{
				if(getRequest('secretKey')!=$secretKey)
				{
					return false;
				}
				else
				{
					return true;
				}	
			}
			else
			{
				$eshopId = getRequest('eshopId');
				$orderId = getRequest('orderId');
				$serviceName = getRequest('serviceName');
				$eshopAccount = getRequest('eshopAccount');
				$recipientAmount = getRequest('recipientAmount');
				$recipientCurrency = getRequest('recipientCurrency');
				$paymentStatus = getRequest('paymentStatus');
				$userName = getRequest('userName');
				$userEmail = getRequest('userEmail');
				$paymentDate = getRequest('paymentData');			
				$hash  = getRequest("hash");
				$check = md5("{$eshopId}::{$orderId}::{$serviceName}::{$eshopAccount}::{$recipientAmount}::{$recipientCurrency}::{$paymentStatus}::{$userName}::{$userEmail}::{$paymentDate}::{$secretKey}");
				
				return (bool)(strcasecmp($hash, $check) == 0);
			}
		}
	};
?>
